//
//  SettingsViewController.swift
//  Sense2
//
//  Created by Daniel Hauagge on 2/3/16.
//  Copyright © 2016 Daniel Hauagge. All rights reserved.
//

import UIKit

protocol SettingsViewControllerDelegate: class {
    func settingsViewControllerFinished(red : CGFloat, green : CGFloat, blue : CGFloat, brushRadius: CGFloat, useForceTouch: Bool)
}

class SettingsViewController: UIViewController {

    @IBOutlet weak var brushPreviewView: BrushPreviewView!
    
    var delegate: SettingsViewControllerDelegate?
    
    var red: CGFloat = 0
    var green: CGFloat = 0
    var blue: CGFloat = 0
    
    var brushRadius: CGFloat = 10
    var useForceTouch = true
    
    @IBOutlet weak var redSlider: UISlider!
    @IBOutlet weak var greenSlider: UISlider!
    @IBOutlet weak var blueSlider: UISlider!
    @IBOutlet weak var brushSizeSlider: UISlider!
    @IBOutlet weak var forceTouchSwitch: UISwitch!
    
    override func viewDidLoad() {
        super.viewDidLoad()
    }
    
    @IBAction func redSliderDidChange(sender: UISlider) {
        red = CGFloat(sender.value)
        updateColorView()
    }

    @IBAction func greenSliderDidChange(sender: UISlider) {
        green = CGFloat(sender.value)
        updateColorView()
    }
    
    @IBAction func blueSliderDidChange(sender: UISlider) {
        blue = CGFloat(sender.value)
        updateColorView()
    }
    
    @IBAction func brushSizeDidChange(sender: UISlider) {
        brushRadius = CGFloat(sender.value)
        updateColorView()
    }
    
    @IBAction func forceTouchSwitchChanged(sender: UISwitch) {
        useForceTouch = sender.on
        updateColorView()
    }
    
    override func viewWillAppear(animated: Bool) {
        self.redSlider.value = Float(red)
        self.greenSlider.value = Float(green)
        self.blueSlider.value = Float(blue)
        self.brushSizeSlider.value = Float(brushRadius)
        self.forceTouchSwitch.on = useForceTouch
        updateColorView()
    }
    
    func updateColorView() {
//        self.colorView.backgroundColor = UIColor(colorLiteralRed: Float(red),
//            green: Float(green), blue: Float(blue), alpha: 1.0)
        
        self.brushPreviewView.brushColor = UIColor(colorLiteralRed: Float(red),
            green: Float(green), blue: Float(blue), alpha: 1.0)
        self.brushPreviewView.brushRadius = self.brushRadius
    }
    
    @IBAction func buttonDonePressed(sender: AnyObject) {
        dismissViewControllerAnimated(true, completion: nil)
        
        // If the delegate was set (in our case the main view), then call this method
        // to let the view know what was the final color the user picked
        self.delegate?.settingsViewControllerFinished(red, green: green, blue: blue, brushRadius: brushRadius, useForceTouch: useForceTouch)
    }
}
